searchData={"items":[{"type":"module","title":"AirbrakeEx","doc":"This module provides functions to report any kind of exception to\n[Airbrake](https://airbrake.io/).","ref":"AirbrakeEx.html"},{"type":"module","title":"Configuration - AirbrakeEx","doc":"The `project_key` and `project_id` parameters must be set\nin your application environment, usually defined in your `config/config.exs` or,\nif you are setting them with environment variables, then wherever you do that\n(`config/runtime.exs`, `rel/config.exs`, etc). `logger_level` and `environment` are optional.\nTo use an [Errbit](https://github.com/errbit/errbit) instance rather than Airbrake, set\n`:endpoint` to your custom url.\n\n```elixir\nconfig :airbrake_ex,\n  project_key: \"abcdef12345\",\n  project_id: 123456,\n  logger_level: :error,\n  environment: Mix.env,\n  endpoint: \"http://errbit.yourdomain.com\"\n```","ref":"AirbrakeEx.html#module-configuration"},{"type":"module","title":"Usage - AirbrakeEx","doc":"```elixir\ntry do\n  IO.inspect(\"test\",[],\"\")\nrescue\n  exception -> AirbrakeEx.notify(exception, __STACKTRACE__)\nend\n```\n\nYou can ignore certain types of errors by specifying the `:ignore` config key:\n\n```elixir\nconfig :airbrake_ex,\n  ...\n  # List form\n  ignore: [Phoenix.Router.NoRouteError]\n  # OR\n  # Function\n  ignore: fn(error) ->\n    cond do\n      error.type == Phoenix.Router.NoRouteError -> true\n      String.contains?(error.message, \"Ecto.NoResultsError\") -> true\n      true -> false\n    end\n  end\n```","ref":"AirbrakeEx.html#module-usage"},{"type":"function","title":"AirbrakeEx.notify/3","doc":"Notify `airbrake` about a new exception","ref":"AirbrakeEx.html#notify/3"},{"type":"function","title":"Parameters - AirbrakeEx.notify/3","doc":"- exception: Exception to notify\n  - stacktrace: the __STACKTRACE__ from the catch/rescue block\n  - options: Options","ref":"AirbrakeEx.html#notify/3-parameters"},{"type":"function","title":"Options - AirbrakeEx.notify/3","doc":"Options that are sent to `airbrake` with exceptions:\n\n  - context\n  - session\n  - params\n  - environment","ref":"AirbrakeEx.html#notify/3-options"},{"type":"module","title":"AirbrakeEx.Config","doc":"This module handles smart fetching of values from the config","ref":"AirbrakeEx.Config.html"},{"type":"function","title":"AirbrakeEx.Config.get/3","doc":"Fetches a value from config, or environment if {:system, \"VAR\"} is provided.\nAn optional default value can be provided, if desired.","ref":"AirbrakeEx.Config.html#get/3"},{"type":"module","title":"AirbrakeEx.LoggerBackend","doc":"A Logger backend to send exceptions from logs to `airbrake`","ref":"AirbrakeEx.LoggerBackend.html"},{"type":"module","title":"Usage - AirbrakeEx.LoggerBackend","doc":"```elixir\nconfig :logger,\n  backends: [AirbrakeEx.LoggerBackend]\n```","ref":"AirbrakeEx.LoggerBackend.html#module-usage"},{"type":"function","title":"AirbrakeEx.LoggerBackend.code_change/3","doc":"","ref":"AirbrakeEx.LoggerBackend.html#code_change/3"},{"type":"function","title":"AirbrakeEx.LoggerBackend.handle_call/2","doc":"","ref":"AirbrakeEx.LoggerBackend.html#handle_call/2"},{"type":"function","title":"AirbrakeEx.LoggerBackend.handle_event/2","doc":"","ref":"AirbrakeEx.LoggerBackend.html#handle_event/2"},{"type":"function","title":"AirbrakeEx.LoggerBackend.handle_info/2","doc":"","ref":"AirbrakeEx.LoggerBackend.html#handle_info/2"},{"type":"function","title":"AirbrakeEx.LoggerBackend.init/1","doc":"","ref":"AirbrakeEx.LoggerBackend.html#init/1"},{"type":"function","title":"AirbrakeEx.LoggerBackend.terminate/2","doc":"","ref":"AirbrakeEx.LoggerBackend.html#terminate/2"},{"type":"module","title":"AirbrakeEx.Plug","doc":"Add the `AirbrakeEx.Plug` to you web application Plug stack\nto send all exceptions to `airbrake`\n\n```elixir\ndefmodule YourApp.Router do\n  use Phoenix.Router\n  use AirbrakeEx.Plug\n\n  # ...\nend\n```","ref":"AirbrakeEx.Plug.html"},{"type":"module","title":"AirbrakeEx.Utils","doc":"","ref":"AirbrakeEx.Utils.html"},{"type":"function","title":"AirbrakeEx.Utils.detuple/1","doc":"","ref":"AirbrakeEx.Utils.html#detuple/1"},{"type":"function","title":"AirbrakeEx.Utils.filter/2","doc":"","ref":"AirbrakeEx.Utils.html#filter/2"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}